@@ -111,6 +111,8 @@ namespace Banshee.Gui.TrackEditor
             BuildHeader ();
             BuildNotebook ();
             BuildFooter ();
+
+            LoadModifiers ();
             
             LoadTrackToEditor ();
         }
@@ -154,7 +156,7 @@ namespace Banshee.Gui.TrackEditor
             header_image_frame.Add (header_image);
             
             header.Attach (header_image_frame, 0, 1, 0, 3,
-                AttachOptions.Shrink, AttachOptions.Expand, 0, 0);
+                AttachOptions.Fill, AttachOptions.Expand, 0, 0);
             
             AddHeaderRow (header, 0, Catalog.GetString ("Title:"), out header_title_label);
             AddHeaderRow (header, 1, Catalog.GetString ("Artist:"), out header_artist_label);
@@ -174,6 +176,7 @@ namespace Banshee.Gui.TrackEditor
             
             label = new Label ();
             label.Xalign = 0.0f;
+            label.Ellipsize = Pango.EllipsizeMode.End;
             header.Attach (label, 2, 3, row, row + 1, 
                 AttachOptions.Fill | AttachOptions.Expand, AttachOptions.Expand, 0, 0);
         }
@@ -261,7 +264,7 @@ namespace Banshee.Gui.TrackEditor
                 HBox box = new HBox ();
                 box.Spacing = 2;
                 box.PackStart (new Image (Stock.Copy, IconSize.Button), false, false, 0);
-                box.PackStart (new Label (Catalog.GetString ("Sync all field values")), false, false, 0);
+                box.PackStart (new Label (Catalog.GetString ("Sync all field _values")), false, false, 0);
                 alignment.Add (box);
                 sync_all_button.Add (alignment);
                 
@@ -282,6 +285,18 @@ namespace Banshee.Gui.TrackEditor
             main_vbox.PackStart (button_box, false, false, 0);
             button_box.ShowAll ();
         }
+
+        private void LoadModifiers ()
+        {
+            foreach (TypeExtensionNode node in AddinManager.GetExtensionNodes ("/Banshee/Gui/TrackEditor/Modifier")) {
+                try {
+                    ITrackEditorModifier mod = (ITrackEditorModifier)node.CreateInstance ();
+                    mod.Modify (this);
+                } catch (Exception e) {
+                    Hyena.Log.Exception ("Failed to initialize TrackEditor/Modifier extension node. Ensure it implements ITrackEditorModifier.", e);
+                }
+            }
+        }
         
         public void ForeachWidget<T> (WidgetAction<T> action) where T : class
         {
@@ -382,8 +397,21 @@ namespace Banshee.Gui.TrackEditor
                 nav_backward_button.Sensitive = CanGoBackward;
                 nav_forward_button.Sensitive = CanGoForward;
             }
+
+            // If there was a widget focused already (eg the Title entry), GrabFocus on it,
+            // which causes its text to be selected, ready for editing.
+            Widget child = FocusChild;
+            while (child != null) {
+                Container container = child as Container;
+                if (container != null) {
+                    child = container.FocusChild;
+                } else if (child != null) {
+                    child.GrabFocus ();
+                    child = null;
+                }
+            }
         }
-        
+
         public void ForeachNonCurrentTrack (EditorTrackOperationClosure closure)
         {
             for (int i = 0; i < TrackCount; i++) {
@@ -528,29 +556,12 @@ namespace Banshee.Gui.TrackEditor
             TrackInfo.ExportableMerge (track, track.SourceTrack);
             track.SourceTrack.Save ();
                 
-            if (LibrarySchema.WriteMetadata.Get ()) {
-                SaveToFile (track.SourceTrack);
-            }
-
-            if (LibrarySchema.MoveOnInfoSave.Get ()) {
-                MoveSavedFile (track.SourceTrack);
-            }
-
-            if (track.SourceTrack == ServiceManager.PlayerEngine.CurrentTrack) {
+            if (track.SourceTrack.TrackEqual (ServiceManager.PlayerEngine.CurrentTrack)) {
+                TrackInfo.ExportableMerge (track, ServiceManager.PlayerEngine.CurrentTrack);
                 ServiceManager.PlayerEngine.TrackInfoUpdated ();
             }
         }
         
-        private void SaveToFile (TrackInfo track)
-        {
-            Scheduler.Schedule (new Banshee.Streaming.SaveTrackMetadataJob (track), JobPriority.Highest);
-        }
-
-        private void MoveSavedFile (TrackInfo track)
-        {
-            Scheduler.Schedule (new MoveOnInfoSaveJob (track), JobPriority.Highest);
-        }
-
 #endregion
 
 #region Static Helpers
