@@ -49,12 +49,12 @@ namespace Hyena.Widgets
         
         protected virtual double AccelerateCore (double velocity)
         {
-            return velocity + 3;
+            return velocity + 8;
         }
         
         protected virtual double DecelerateCore (double velocity)
         {
-            return velocity - 2;
+            return velocity - Math.Max (3, 0.2 * velocity);
         }
         
         private double TargetValue {
@@ -71,6 +71,7 @@ namespace Hyena.Widgets
             }
         }
         
+        // Smoothly get us to the target value
         private bool OnTimeout ()
         {
             double delta = target_value - value;
@@ -91,8 +92,13 @@ namespace Hyena.Widgets
             }
             
             velocity = hypothetical <= 0 ? Decelerate (velocity) : Accelerate (velocity);
-            
-            value += Math.Max (velocity, 1) * sign;
+
+            // Minimum speed: 2 px / 20 ms = 100px / second
+            value = Math.Round (value + Math.Max (velocity, 2) * sign);
+
+            // Don't go past the target value
+            value = (sign == 1) ? Math.Min (value, target_value) : Math.Max (value, target_value);
+
             ignore_value_changed = true;
             Vadjustment.Value = Math.Round (value);
             ignore_value_changed = false;
